@@ -31,8 +31,12 @@ def install():
         for item in carrier:
             if item.key.capitalize() in headers:
                 item.val = headers[item.key.capitalize()]
+            if item.key.upper() in headers:
+                item.val = headers[item.key.upper()]
             if trace_id_name.capitalize() in headers and type(item) is Carrier:
                 item.set_frontend_trace_id(headers[trace_id_name.capitalize()])
+            if trace_id_name.upper() in headers and type(item) is Carrier:
+                item.set_frontend_trace_id(headers[trace_id_name.upper()])
         with context.new_entry_span(op="/", carrier=carrier) as span:
             span.layer = Layer.Http
             span.component = ComponentType.Falcon
@@ -95,11 +99,10 @@ def install():
         elif reader_type == ReaderType.QueryString:
             # import json
             # raw = request.stream.read()
-            raw_json = request.bounded_stream.read()
-            from urllib import parse
-            params = parse.parse_qsl(raw_json)
-            if request.method == "GET":
-                code = request.params.get(reader.get("ReaderKey"), "")
+            # raw_json = request.bounded_stream.read()
+            # from urllib import parse
+            # params = parse.parse_qsl(raw_json)
+            code = request.params.get(reader.get("ReaderKey"), "")
         elif reader_type == ReaderType.Environment:
             import os
 
