@@ -31,15 +31,17 @@ def install():
     def params_tostring(msg, level):
         return {"err_msg": msg, "err_type": level, "err_trace": ""}
 
-    def _fast_py38_handle(this: logging.Logger, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1):
+    def _fast_py38_handle(
+        this: logging.Logger, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1
+    ):
         if log_level.get(config.log_level) <= level:
             context = get_context()
-            with context.new_exit_span(op="Log", peer="") as span:
+            with context.new_local_span(op="Log") as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
 
                 data = params_tostring(msg, level)
-                level_names = {v:k for k, v in log_level.items()}
+                level_names = {v: k for k, v in log_level.items()}
                 span.logs.append(Log(items=[LogItem(key=level_names.get(level, "USER_UNKNOWN"), val=data)]))
 
                 res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
@@ -54,12 +56,12 @@ def install():
     def _fast_py35_handle(this: logging.Logger, level, msg, args, exc_info=None, extra=None):
         if log_level.get(config.log_level) <= level:
             context = get_context()
-            with context.new_exit_span(op="Log", peer="") as span:
+            with context.new_local_span(op="Log") as span:
                 span.layer = Layer.Log
                 span.component = ComponentType.Log
 
                 data = params_tostring(msg, level)
-                level_names = {v:k for k, v in log_level.items()}
+                level_names = {v: k for k, v in log_level.items()}
                 span.logs.append(Log(items=[LogItem(key=level_names.get(level, "USER_UNKNOWN"), val=data)]))
 
                 res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
@@ -72,6 +74,7 @@ def install():
             return res
 
     from sys import version_info
+
     python_version = version_info[:2]
     if python_version >= (3, 8):
         functions.log("minor python version is:%r", version_info[:2])
@@ -79,4 +82,3 @@ def install():
     else:
         functions.log("python version is:%r", version_info[:2])
         logging.Logger._log = _fast_py35_handle
-
